The Bionic version of pthread_create used on Android calls the prctl
function to give the stack and thread local storage a useful name. This
will cause the KILL_THREAD test to fail as it will kill the thread as
soon as it is created.

change the test to use getpid instead of prctl.

Signed-off-by: Terry Tritton <terry.trit...@linaro.org>
---
 tools/testing/selftests/seccomp/seccomp_bpf.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/tools/testing/selftests/seccomp/seccomp_bpf.c 
b/tools/testing/selftests/seccomp/seccomp_bpf.c
index 5e705674b706..da11b95b8872 100644
--- a/tools/testing/selftests/seccomp/seccomp_bpf.c
+++ b/tools/testing/selftests/seccomp/seccomp_bpf.c
@@ -784,7 +784,7 @@ void *kill_thread(void *data)
        bool die = (bool)data;
 
        if (die) {
-               prctl(PR_GET_SECCOMP, 0, 0, 0, 0);
+               syscall(__NR_getpid);
                return (void *)SIBLING_EXIT_FAILURE;
        }
 
@@ -803,11 +803,11 @@ void kill_thread_or_group(struct __test_metadata 
*_metadata,
 {
        pthread_t thread;
        void *status;
        /* Kill only when calling __NR_prctl. */
        struct sock_filter filter_thread[] = {
                BPF_STMT(BPF_LD|BPF_W|BPF_ABS,
                        offsetof(struct seccomp_data, nr)),
-               BPF_JUMP(BPF_JMP|BPF_JEQ|BPF_K, __NR_prctl, 0, 1),
+               BPF_JUMP(BPF_JMP|BPF_JEQ|BPF_K, __NR_getpid, 0, 1),
                BPF_STMT(BPF_RET|BPF_K, SECCOMP_RET_KILL_THREAD),
                BPF_STMT(BPF_RET|BPF_K, SECCOMP_RET_ALLOW),
        };
@@ -819,7 +819,7 @@ void kill_thread_or_group(struct __test_metadata *_metadata,
        struct sock_filter filter_process[] = {
                BPF_STMT(BPF_LD|BPF_W|BPF_ABS,
                        offsetof(struct seccomp_data, nr)),
-               BPF_JUMP(BPF_JMP|BPF_JEQ|BPF_K, __NR_prctl, 0, 1),
+               BPF_JUMP(BPF_JMP|BPF_JEQ|BPF_K, __NR_getpid, 0, 1),
                BPF_STMT(BPF_RET|BPF_K, kill),
                BPF_STMT(BPF_RET|BPF_K, SECCOMP_RET_ALLOW),
        };
@@ -803,11 +803,11 @@ void kill_thread_or_group(struct __test_metadata 
        pthread_t thread;
        void *status;
-       /* Kill only when calling __NR_prctl. */
+       /* Kill only when calling __NR_getpid. */
        struct sock_filter filter_thread[] = {
                BPF_STMT(BPF_LD|BPF_W|BPF_ABS,
-- 
2.43.0.429.g432eaa2c6b-goog


Reply via email to